"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateErrors = void 0;
const mustache_1 = require("mustache");
const path_1 = __importDefault(require("path"));
const config_1 = require("../config");
const utils_1 = require("./utils");
/**
 * Generate client and server errors.
 */
async function generateErrors() {
    const settings = {
        ...config_1.ClientErrorSettings,
        ...config_1.ServerErrorSettings
    };
    const destDirPath = path_1.default.join(__dirname, '..', 'errors');
    const items = [];
    const tpl = await utils_1.loadTemplate('error.tpl');
    for (let key in settings) {
        const isServerError = utils_1.hasOwnProperty(config_1.ServerErrorSettings, key);
        const pathSuffix = isServerError ? 'server' : 'client';
        const fileName = settings[key].statusCode + '-' + (settings[key].code).toLowerCase().replaceAll('_', '-') + '.ts';
        const destFilePath = path_1.default.join(destDirPath, pathSuffix, fileName);
        let className = key;
        const classErrorSuffix = key.toLocaleLowerCase().endsWith('error');
        if (!classErrorSuffix) {
            className += 'Error';
        }
        const baseClassName = isServerError ? 'ServerError' : 'ClientError';
        const content = mustache_1.render(tpl, {
            namespaceFile: 'index.ts',
            decorateMessage: isServerError,
            logMessage: isServerError,
            class: className,
            baseClass: baseClassName,
            ...settings[key]
        });
        await utils_1.saveFile(content, destFilePath);
        items.push({
            fileName,
            isServerError
        });
    }
    // default
    const lines = [
        `export * from "./base";`
    ];
    items.map(item => {
        const parts = item.fileName.split('.');
        parts.pop();
        const relativeDirectory = item.isServerError ? 'server' : 'client';
        lines.push(`export * from "./${relativeDirectory}/${parts.join('.')}";`);
    });
    let content = lines.join("\n");
    let destFilePath = path_1.default.join(destDirPath + '/index.ts');
    await utils_1.saveFile(content, destFilePath);
}
exports.generateErrors = generateErrors;
//# sourceMappingURL=index.js.map